<?php

namespace Litecms\ContractSetting\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\ContractSetting\Http\Requests\ContractSettingRequest;
use Litecms\ContractSetting\Interfaces\ContractSettingRepositoryInterface;
use Litecms\ContractSetting\Models\ContractSetting;

/**
 * Resource controller class for contract_setting.
 */
class ContractSettingResourceController extends BaseController
{

    /**
     * Initialize contract_setting resource controller.
     *
     * @param type ContractSettingRepositoryInterface $contract_setting
     *
     * @return null
     */
    public function __construct(ContractSettingRepositoryInterface $contract_setting)
    {
        parent::__construct();
        $this->repository = $contract_setting;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\ContractSetting\Repositories\Criteria\ContractSettingResourceCriteria::class);
    }

    /**
     * Display a list of contract_setting.
     *
     * @return Response
     */
    public function index(ContractSettingRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\ContractSetting\Repositories\Presenter\ContractSettingPresenter::class)
                ->$function();
        }

        $contract_settings = $this->repository->paginate();

        return $this->response->title(trans('contract_setting::contract_setting.names'))
            ->view('contract_setting::contract_setting.index', true)
            ->data(compact('contract_settings'))
            ->output();
    }

    /**
     * Display contract_setting.
     *
     * @param Request $request
     * @param Model   $contract_setting
     *
     * @return Response
     */
    public function show(ContractSettingRequest $request, ContractSetting $contract_setting)
    {

        if ($contract_setting->exists) {
            $view = 'contract_setting::contract_setting.show';
        } else {
            $view = 'contract_setting::contract_setting.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('contract_setting::contract_setting.name'))
            ->data(compact('contract_setting'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new contract_setting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ContractSettingRequest $request)
    {

        $contract_setting = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('contract_setting::contract_setting.name')) 
            ->view('contract_setting::contract_setting.create', true) 
            ->data(compact('contract_setting'))
            ->output();
    }

    /**
     * Create new contract_setting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ContractSettingRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $contract_setting                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('contract_setting::contract_setting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('contract_setting/contract_setting/' . $contract_setting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/contract_setting/contract_setting'))
                ->redirect();
        }

    }

    /**
     * Show contract_setting for editing.
     *
     * @param Request $request
     * @param Model   $contract_setting
     *
     * @return Response
     */
    public function edit(ContractSettingRequest $request, ContractSetting $contract_setting)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('contract_setting::contract_setting.name'))
            ->view('contract_setting::contract_setting.edit', true)
            ->data(compact('contract_setting'))
            ->output();
    }

    /**
     * Update the contract_setting.
     *
     * @param Request $request
     * @param Model   $contract_setting
     *
     * @return Response
     */
    public function update(ContractSettingRequest $request, ContractSetting $contract_setting)
    {
        try {
            $attributes = $request->all();

            $contract_setting->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('contract_setting::contract_setting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('contract_setting/contract_setting/' . $contract_setting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('contract_setting/contract_setting/' . $contract_setting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the contract_setting.
     *
     * @param Model   $contract_setting
     *
     * @return Response
     */
    public function destroy(ContractSettingRequest $request, ContractSetting $contract_setting)
    {
        try {

            $contract_setting->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('contract_setting::contract_setting.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('contract_setting/contract_setting/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('contract_setting/contract_setting/' . $contract_setting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple contract_setting.
     *
     * @param Model   $contract_setting
     *
     * @return Response
     */
    public function delete(ContractSettingRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('contract_setting::contract_setting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('contract_setting/contract_setting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/contract_setting/contract_setting'))
                ->redirect();
        }

    }

    /**
     * Restore deleted contract_settings.
     *
     * @param Model   $contract_setting
     *
     * @return Response
     */
    public function restore(ContractSettingRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('contract_setting::contract_setting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/contract_setting/contract_setting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/contract_setting/contract_setting/'))
                ->redirect();
        }

    }

}
